@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.74';
+  $CPAN::Perl::Releases::VERSION = '0.76';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -220,6 +220,10 @@ our $data =
     "tar.bz2" => "D/DO/DOM/perl-5.14.3-RC2.tar.bz2",
     "tar.gz" => "D/DO/DOM/perl-5.14.3-RC2.tar.gz",
   },
+  "5.14.3" => {
+    "tar.bz2" => "D/DO/DOM/perl-5.14.3.tar.bz2",
+    "tar.gz" => "D/DO/DOM/perl-5.14.3.tar.gz",
+  },
   "5.15.0" => {
     "tar.bz2" => "D/DA/DAGOLDEN/perl-5.15.0.tar.bz2",
     "tar.gz" => "D/DA/DAGOLDEN/perl-5.15.0.tar.gz",
@@ -411,7 +415,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.74
+version 0.76
 
 =head1 SYNOPSIS
 
